import { AnyOS } from './getos';
export interface BaseDryMongoBinaryOptions {
    version?: string;
    downloadDir?: string;
    os?: AnyOS;
    arch?: string;
    systemBinary?: string;
}
export interface DryMongoBinaryOptions extends BaseDryMongoBinaryOptions {
    version: NonNullable<BaseDryMongoBinaryOptions['version']>;
}
export interface DryMongoBinaryNameOptions {
    version: NonNullable<DryMongoBinaryOptions['version']>;
    arch: NonNullable<DryMongoBinaryOptions['arch']>;
    os: NonNullable<DryMongoBinaryOptions['os']>;
}
export interface DryMongoBinaryPaths {
    resolveConfig: string;
    legacyHomeCache: string;
    modulesCache: string;
    relative: string;
}
/**
 * Locate an Binary, without downloading / locking
 */
export declare class DryMongoBinary {
    /**
     * Binaries already found, values are: [Version, Path]
     */
    static binaryCache: Map<string, string>;
    /**
     * Cache the "getOS" call, so that not much has to be re-executed over and over
     */
    static cachedGetOs: AnyOS;
    /**
     * Try to locate an existing binary
     * @returns The Path to an Binary Found, or undefined
     */
    static locateBinary(opts: DryMongoBinaryOptions): Promise<string | undefined>;
    /**
     * Generate All required options for the binary name / path generation
     */
    static generateOptions(opts?: DryMongoBinaryOptions): Promise<Required<DryMongoBinaryOptions>>;
    /**
     * Get the full path with filename
     * @return Absoulte Path with FileName
     */
    static getBinaryName(opts: DryMongoBinaryNameOptions): string;
    /**
     * Combine basePath with binaryName
     */
    static combineBinaryName(basePath: string, binaryName: string): string;
    /**
     * Probe if the provided "systemBinary" is an existing path
     * @param systemBinary The Path to probe for an System-Binary
     * @return System Binary path or undefined
     */
    static getSystemPath(systemBinary: string): Promise<string | undefined>;
    /**
     * Generate an "MongoBinaryPaths" object
     *
     * This Function should not hit the FileSystem
     * @return an finished "MongoBinaryPaths" object
     */
    static generatePaths(opts: DryMongoBinaryOptions & DryMongoBinaryNameOptions): Promise<DryMongoBinaryPaths>;
    /**
     * Generate the Path where an Binary will be located
     * @return "boolean" indicating if the binary exists at the provided path, and "string" the path to use for the binary
     */
    static generateDownloadPath(opts: DryMongoBinaryOptions & DryMongoBinaryNameOptions): Promise<[boolean, string]>;
    /**
     * This function is used, because jest just dosnt want "os.homedir" to be mocked
     * if someone can find an way to actually mock this in an test, please change it
     */
    private static homedir;
}
//# sourceMappingURL=DryMongoBinary.d.ts.map